import requests
import json
from base64 import b64encode
import hashlib

class Monnify:
    def __init__(self, apiKey, clientSecretKey):
        self.apiKey = apiKey
        self.clientSecretKey = clientSecretKey

    """ Generates Token"""
    def generateToken(self):
        data = f"{self.apiKey}:{self.clientSecretKey}".encode()
        userAndPass = b64encode(data).decode("ascii")
        headers = { 'Authorization' : 'Basic %s' %  userAndPass }
        #print(headers)
        url = "https://sandbox.monnify.com/api/v1/auth/login"
        r = requests.post(url, headers=headers)
        loadJson = json.loads(r.content)
        #print(loadJson['responseBody']['accessToken'])
        token = loadJson['responseBody']['accessToken']
        return token

    """ Create Reserve Account"""
    def createReserveAccount(self, accountReference, accountName, currencyCode, contractCode, customerEmail, customerName):
        rHeaders = {'Content-Type':"application/json", 'Authorization':"Bearer {0}".format(self.generateToken())}
        reserveAccUrl = "https://sandbox.monnify.com/api/v1/bank-transfer/reserved-accounts"
        data = {
            "accountReference":accountReference,
            "accountName":accountName,
            "currencyCode":currencyCode,
            "contractCode":contractCode,
            "customerEmail":customerEmail,
            "customerName":customerName
            }
        createReserveAccount = requests.post(reserveAccUrl, data=json.dumps(data), headers=rHeaders)
        reserverR = json.loads(createReserveAccount.content)
        #print("==>", reserverR)
        return reserverR


    """ Check verify valid payment"""
    def createHashFromWebhook(self, paymentReference, amountPaid, paidOn, transactionReference):
        to_hash = f'{self.clientSecretKey}|{paymentReference}|{amountPaid}|{paidOn}|{transactionReference}'
        hash_value = hashlib.sha512(to_hash.encode()).hexdigest()
        return hash_value
    

    """GET TRANSACTION DETAILS"""
    def getTranasactionDetails(self,transactionReference):
        rHeaders = {'Content-Type':"application/json", 'Authorization':"Bearer {0}".format(self.generateToken())}
        url = 'https://sandbox.monnify.com/api/v2/transactions/'+transactionReference
        getTrans = requests.get(url, headers=rHeaders)
        details = json.loads(getTrans.content)
        return details


import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='python_monnify',
    version='0.2',
    zip_safe=False,
    include_package_data=True,
    packages=find_packages(),
    license='MIT License',  # example license
    description='A Library created for ease of using monnify\'s API to create unique account numbers for your users/members, verify user transaction, generate Bearer Token etc..',
    long_description_content_type='text/plain',
    long_description=README,
    url='https://github.com/ldonjibson/python_monnify',
    author='Olayanju A. Ajibola',
    author_email='vtubusinessportal@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',  # example license
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        # Replace these appropriately if you are stuck on Python 2.
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
